summaryrefslogtreecommitdiffstats
path: root/lib/util/rurl.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/util/rurl.h')
-rw-r--r--lib/util/rurl.h58
1 files changed, 29 insertions, 29 deletions
diff --git a/lib/util/rurl.h b/lib/util/rurl.h
index 342b3e3d..5ab2ec73 100644
--- a/lib/util/rurl.h
+++ b/lib/util/rurl.h
@@ -23,33 +23,33 @@ public:
name/name/ are directories
name/name are files.
Trailing slash will be deleted for files (type == File).*/
- Name(const QString &rurl, const Type type = Auto);
+ Name(const TQString &rurl, const Type type = Auto);
Name(const char *rurl, const Type type = Auto);
/**Sets the relative name.*/
- void setRURL(const QString &rurl, const Type type);
+ void setRURL(const TQString &rurl, const Type type);
/**Gets the relative name in form
dir/dir/ -> directory
or
dir/dir/file -> file.*/
- QString rurl() const;
+ TQString rurl() const;
/**Adds addendum to the directory path. This honors file names so
if RName represents /dir1/dir2/fname.ext
addPath(dir3) will change RName to /dir1/dir2/dir3/fname.ext*/
- void addPath(const QString &addendum);
+ void addPath(const TQString &addendum);
/**Removes "//" from the name.*/
void cleanRURL();
/**Returns the extension of a file or QString::null for directories.
If complete is true then returns extensions like "tar.gz".
Else returns "gz".*/
- QString extension(bool complete = true) const;
- /**Returns the name of the file without the path or QString::null
+ TQString extension(bool complete = true) const;
+ /**Returns the name of the file without the path or TQString::null
for directories.*/
- QString fileName() const;
- /**Returns the name of the directory or QString::null if there are no dirs in path.*/
- QString directory() const;
+ TQString fileName() const;
+ /**Returns the name of the directory or TQString::null if there are no dirs in path.*/
+ TQString directory() const;
/**Returns true if the type of RName is file.*/
bool isFile() const;
@@ -66,12 +66,12 @@ public:
/**Creates and returns relative name between base and url. Base and url should be absolute.
Base is considered to be a directory.*/
- static Name relativeName(const QString &base, const QString &url);
+ static Name relativeName(const TQString &base, const TQString &url);
/**Cleans rurl by removing extra slashes.*/
- static QString cleanName(const QString &rurl);
+ static TQString cleanName(const TQString &rurl);
/**Corrects rurl according to the given type and returns corrected url.
Also cleans url (see @ref cleanRURL).*/
- static QString correctName(const QString &rurl, const Type type = Auto);
+ static TQString correctName(const TQString &rurl, const Type type = Auto);
bool operator == (const Name &rname);
bool operator != (const Name &rname);
@@ -83,7 +83,7 @@ protected:
void correct();
private:
- QString m_rurl;
+ TQString m_rurl;
Type m_type;
};
@@ -97,17 +97,17 @@ public:
URL(KURL base, KURL url, Type type = Auto);
/**Creates RURL object with given base and relative or full url (according to
the isUrlRelative value).*/
- URL(KURL base, QString url, bool isUrlRelative, Type type = Auto);
+ URL(KURL base, TQString url, bool isUrlRelative, Type type = Auto);
/**Sets a new base for a RURL.*/
void setBase(const KURL &base);
/**Sets a new base for a RURL. Base is is considered to be a
directory and converted to KURL using KURL::setPath().*/
- void setBase(const QString &base);
+ void setBase(const TQString &base);
/**Returns RURL base.*/
KURL base() const;
/**Returns a path of a base KURL (using KURL::path()). Trailing slash is guaranteed.*/
- QString basePath() const;
+ TQString basePath() const;
/**Returns a complete url to the RURL location. This is basically base + rurl.
This also resolves ".." components in path.
@@ -120,13 +120,13 @@ public:
This method only returns a path part of the KURL (using KURL::path()).
Trailing slash is guaranteed for directories and no trailing slash - for files.
This also resolves ".." components in path.*/
- QString urlPath() const;
+ TQString urlPath() const;
/**Returns a directory of a complete url to the location. The url is constructed as base + rurl.
Returns the same as urlPath() for directories.
This method uses KURL::directory to determine the directory.
Trailing slash is guaranteed.
This also resolves ".." components in path.*/
- QString urlDirectory() const;
+ TQString urlDirectory() const;
/**Returns a new URL that is relative to given base. Relative part is taken from
current URL object.*/
@@ -136,7 +136,7 @@ public:
static URL relativeURL(KURL base, KURL url);
/**Returns a new relative URL constructed from base and given url. url parameter
is either relative or full (depends on isUrlRelative value).*/
- static URL relativeURL(KURL base, QString url, bool isUrlRelative);
+ static URL relativeURL(KURL base, TQString url, bool isUrlRelative);
bool operator == (const URL &url);
bool operator != (const URL &url);
@@ -150,14 +150,14 @@ class Directory: public URL{
public:
/**Works as URL::URL(KURL, KURL), only implies Name::Directory mode.*/
Directory(KURL base, KURL url);
- /**Works as URL::URL(KURL, QString, bool), only implies Name::Directory mode.*/
- Directory(KURL base, QString url, bool isRelativeUrl);
+ /**Works as URL::URL(KURL, TQString, bool), only implies Name::Directory mode.*/
+ Directory(KURL base, TQString url, bool isRelativeUrl);
- /**Works as URL::setRURL(QString), only implies Name::Directory mode.*/
- void setRURL(QString rurl);
+ /**Works as URL::setRURL(TQString), only implies Name::Directory mode.*/
+ void setRURL(TQString rurl);
private:
- void setRURL(QString rurl, Type type);
+ void setRURL(TQString rurl, Type type);
};
@@ -167,13 +167,13 @@ public:
/**Works as URL::URL(KURL, KURL), only implies Name::File mode.*/
File(KURL base, KURL url);
/**Works as URL::URL(KURL, KURL), only implies Name::File mode.*/
- File(KURL base, QString url, bool isRelativeUrl);
+ File(KURL base, TQString url, bool isRelativeUrl);
- /**Works as URL::setRURL(QString), only implies Name::File mode.*/
- void setRURL(QString rurl);
+ /**Works as URL::setRURL(TQString), only implies Name::File mode.*/
+ void setRURL(TQString rurl);
private:
- void setRURL(QString rurl, Type type);
+ void setRURL(TQString rurl, Type type);
};
@@ -23,33 +23,33 @@ public:
/**Removes "//" from the name.*/
void cleanRURL();
- /**Returns the extension of a file or QString::null for directories.
+ /**Returns the extension of a file or TQString::null for directories.
If complete is true then returns extensions like "tar.gz".
Else returns "gz".*/